# Xilinx


The {py:mod}`torii.platform.vendor.xilinx` module provides a base platform to support Xilinx devices with the [ISE], [Vivado], and [Symbiflow] toolchains.

```{eval-rst}

.. autoclass:: torii.platform.vendor.xilinx.XilinxPlatform

```

[ISE]:　https://www.xilinx.com/products/design-tools/ise-design-suite.html
[Vivado]:　https://www.xilinx.com/products/design-tools/vivado.html
[Symbiflow]:　https://f4pga.readthedocs.io/projects/prjxray/en/latest/
